@@ -45,6 +45,7 @@ import json
 import logging
 import logging.config
 from typing import Dict, List
+import xml.etree.ElementTree as ET  # pylint: disable=unused-import
 import urllib3
 
 
@@ -145,36 +146,6 @@ def example(
                 disable_ssl_certificate_validation, user_agent='Example')
 
 
-    query = {
-        'ResourceID': ['spase://NASA/NumericalData/ACE/CRIS/L2/P1D',
-            'spase://NASA/NumericalData/ACE/CRIS/L2/PT1H'
-        ],
-#        'InstrumentID': 'spase://SMWG/Instrument/ACE/CRIS',
-#        'ObservatoryID': 'spase://SMWG/Observatory/ACE',
-#        'Cadence': '=PT1H',
-#        'ObservedRegion': 'Heliosphere.NearEarth',
-#        'MeasurementType': 'EnergeticParticles',
-#        'AccessRights': 'Open',
-#        'Format': 'CDF'
-    }
-
-    #result = hdp.get_spase([rt.COLLECTION], {'Description': 'IRIS AND AIA AND SDO AND -HINODE'}, None)
-
-    types = [rt.NUMERICAL_DATA, rt.DISPLAY_DATA]
-    time_range = ['2022-01-01', '2022-01-02']
-    result = hdp.get_spase(types, query, time_range)
-    if result['HttpStatus'] == 200:
-        #print('HDP Spase:')
-        #print(ET.tostring(result['Result']))
-        print('Result ResourceIDs:')
-        for r_id in result['Result'].findall('.//' + ET_SPASE_NS +
-                                             'ResourceID'):
-            print(r_id.text)
-    else:
-        print_error('hdp.get_spase', result)
-
-    #return
-
     result = hdp.get_instrument_ids()
     if result['HttpStatus'] == 200:
         print('HDP InstrumentIDs:')
@@ -209,6 +180,14 @@ def example(
     else:
         print_error('hdp.get_spectral_ranges', result)
 
+    result = hdp.get_phenomenon_types()
+    if result['HttpStatus'] == 200:
+        print('HDP PhenomenonType:')
+        for value in result['PhenomenonType']:
+            print(f'    {value}')
+    else:
+        print_error('hdp.get_phenomenon_types', result)
+
     result = hdp.get_observatory_group_ids()
     if result['HttpStatus'] == 200:
         print('HDP ObservatoryGroupIDs:')
@@ -237,16 +216,84 @@ def example(
         print_error('hdp.get_observed_regions', result)
 
 
+    resource_ids = [
+        'spase://NASA/Collection/IRIS_AIA',
+        'spase://SMWG/Service/CCMC/Models'
+    ]
+    result = hdp.get_spase(resource_ids)
+    if result['HttpStatus'] == 200:
+        #print('HDP Spase:')
+        #print(ET.tostring(result['Result']))
+        print('get_spase Result ResourceIDs:')
+        for spase in result['Result'].findall('.//' + ET_SPASE_NS +
+                                             'Spase'):
+            print(spase.findall('.//' + ET_SPASE_NS + 'ResourceID')[0].text)
+            print('    ', spase.findall('.//' + ET_SPASE_NS + 'ResourceName')[0].text)
+    else:
+        print_error('hdp.get_spase_data', result)
+
+
+
+    query = {
+        'ResourceID': ['spase://NASA/NumericalData/ACE/CRIS/L2/P1D',
+            'spase://NASA/NumericalData/ACE/CRIS/L2/PT1H'
+        ],
+#        'InstrumentID': 'spase://SMWG/Instrument/ACE/CRIS',
+#        'ObservatoryID': 'spase://SMWG/Observatory/ACE',
+#        'Cadence': '=PT1H',
+#        'ObservedRegion': 'Heliosphere.NearEarth',
+#        'MeasurementType': 'EnergeticParticles',
+#        'AccessRights': 'Open',
+#        'Format': 'CDF'
+    }
+    types = [rt.NUMERICAL_DATA, rt.DISPLAY_DATA]
+    time_range = ['2022-01-01', '2022-01-02']
+
+    result = hdp.get_spase_data(types, query, time_range)
+    if result['HttpStatus'] == 200:
+        #print('HDP Spase:')
+        #print(ET.tostring(result['Result']))
+        print('get_spase_data Result ResourceIDs:')
+        for r_id in result['Result'].findall('.//' + ET_SPASE_NS +
+                                             'ResourceID'):
+            print(r_id.text)
+    else:
+        print_error('hdp.get_spase_data', result)
+
+
     query = {
         'ResourceID': ['spase://NASA/NumericalData/ACE/MAG/L2/PT16S', 'bad']
     }
 
-    result = hdp.get_spase(types, query)
+    result = hdp.get_spase_data(types, query)
     if result['HttpStatus'] == 200:
-        print('HDP Spase:')
+        print('get_spase_data Result:')
         print(result['Result'])
     else:
-        print_error('hdp.get_spase', result)
+        print_error('hdp.get_spase_data', result)
+
+
+    query = {
+        'InstrumentID': 'spase://SMWG/Instrument/ACE/MAG',
+        'PhenomenonType': 'MagneticCloud',
+        'Description': 'ICME'
+    }
+    time_range = ['1999-01-01', '1999-01-02']
+
+    result = hdp.get_spase_catalog(query, time_range)
+    if result['HttpStatus'] == 200:
+        #print('HDP Spase:')
+        #print(ET.tostring(result['Result']))
+        print('Result Catalogs:')
+        for catalog in result['Result'].findall('.//' + ET_SPASE_NS +
+                                             'Catalog'):
+            print(catalog.findall('.//' + ET_SPASE_NS + 'ResourceID')[0].text)
+            print('    ', catalog.findall('.//' + ET_SPASE_NS + 'ResourceName')[0].text)
+            #ET.indent(catalog)
+            #print(ET.tostring(catalog, encoding='unicode',
+            #                  default_namespace='http://www.spase-group.org/data/schema'))
+    else:
+        print_error('hdp.get_spase_catalog', result)
 
 
 def print_error(
