@@ -288,6 +288,34 @@ class HdpWs:
                                           'SpectralRange', 'SpectralRange')
 
 
+    def get_phenomenon_types(
+            self
+        ) -> Dict:
+        """
+        Gets all /Spase/PhenomenonType values available at HDP.
+
+        Returns
+        -------
+        Dict
+            Dictionary containing a 'PhenomenonType' key with a value
+            of a List containing all /Spase/PhenomenonType values
+            with the addition of the following key/values:<br>
+            - HttpStatus: with the value of the HTTP status code.
+              Successful == 200.<br>
+            When HttpStatus != 200:<br>
+            - HttpText: containing a string representation of the HTTP
+              entity body.<br>
+            When HttpText is a standard HDP WS error entity body the
+            following key/values (convenience to avoid parsing
+            HttpStatus):<br>
+            - ErrorMessage: value from HttpText.<br>
+            - ErrorDescription: value from HttpText.<br>
+        """
+        return self.__get_simple_resource('Spase/PhenomenonType',
+                                          'PhenomenonType', 
+                                          'PhenomenonType')
+
+
     def get_observatory_group_ids(
             self
         ) -> Dict:
@@ -372,17 +400,69 @@ class HdpWs:
 
     def get_spase(
             self,
-            resource_types: List[ResourceType],
-            query: Dict,
-            date_range: Union[List[str], DateInterval] = None
+            resource_ids: List[str]
         ) -> Dict:
         """
         Gets the specified SPASE documents from HDP.
 
+        Parameters
+        ----------
+        resource_ids
+            List of SPASE ResourceID values of the documents to get.
+
+        Returns
+        -------
+            Dictionary containing a 'Result' key with a value of an
+            ElementTree representation of the results as described by
+            <https://heliophysicsdata.gsfc.nasa.gov/WebServices/hdpspase.xsd>
+            with the addition of the following key/values:<br>
+            - HttpStatus: with the value of the HTTP status code.
+              Successful == 200.<br>
+            When HttpStatus != 200:<br>
+            - HttpText: containing a string representation of the HTTP
+              entity body.<br>
+            When HttpText is a standard HDP WS error entity body the
+            following key/values (convenience to avoid parsing
+            HttpStatus):<br>
+            - ErrorMessage: value from HttpText.<br>
+            - ErrorDescription: value from HttpText.<br>
+        """
+        url = self._endpoint + 'Spase'
+
+        query = {
+            'ResourceID': resource_ids
+        }
+        response = self._session.get(url, params=query,
+                                     timeout=self._timeout)
+
+        self.logger.debug('response.url = %s', response.url)
+
+        status = self.__get_status(response)
+        if response.status_code != 200:
+            return status
+
+        result = {
+            'Result': ET.fromstring(response.text)
+        }
+
+        result.update(status)
+        return result
+
+
+    def get_spase_data(
+            self,
+            resource_types: List[ResourceType],
+            query: Dict,
+            date_range: Union[List[str], DateInterval] = None
+        ) -> Dict:
+        """
+        Gets the specified SPASE "data" documents from HDP.
+
         Parameters
         ----------
         resource_types
-            List of SPASE ResourceTypes to get.
+            List of SPASE ResourceTypes to get.  ResourceType.NUMERICAL_DATA
+            , ResourceType.DISPLAY_DATA, or both.
         query
             Dictionary containing query parameters and values.  For
             example,<pre>
@@ -412,39 +492,58 @@ class HdpWs:
             When HttpStatus != 200:<br>
             - HttpText: containing a string representation of the HTTP
               entity body.<br>
-            When HttpText is a standard SSC WS error entity body the
+            When HttpText is a standard HDP WS error entity body the
             following key/values (convenience to avoid parsing
             HttpStatus):<br>
             - ErrorMessage: value from HttpText.<br>
             - ErrorDescription: value from HttpText.<br>
         """
-        resource_path = ';'.join(type.value for type in resource_types)
-        url = self._endpoint + 'Spase/' + resource_path
+        return self.__get_complex_resource(resource_types, query, date_range)
 
-        if date_range is not None:
 
-            if isinstance(date_range, list):
-                date_interval = DateInterval(date_range[0], date_range[1])
-            else:
-                date_interval = date_range
+    def get_spase_catalog(
+            self,
+            query: Dict,
+            date_range: Union[List[str], DateInterval] = None
+        ) -> Dict:
+        """
+        Gets the specified SPASE Catalog documents from HDP.
 
-            url += '/' + str(date_interval)
+        Parameters
+        ----------
+        query
+            Dictionary containing query parameters and values.  For
+            example,<pre>
+            query = { 
+                'InstrumentID': 'spase://SMWG/Instrument/ACE/MAG',
+                'PhenomenonType': 'MagneticCloud',
+                'Description': 'ICME'
+            }</pre>
+        date_range
+            A DateInterval or two element array of ISO 8601 string
+            values of the start and stop date of the requested resources.
+            for example,<pre>
+            date_range = ['1999-01-01', '1999-01-02']
+            </pre>
 
-        response = self._session.get(url, params=query,
-                                     timeout=self._timeout)
-
-        self.logger.debug('response.url = %s', response.url)
-
-        status = self.__get_status(response)
-        if response.status_code != 200:
-            return status
-
-        result = {
-            'Result': ET.fromstring(response.text)
-        }
-
-        result.update(status)
-        return result
+        Returns
+        -------
+            Dictionary containing a 'Result' key with a value of an
+            ElementTree representation of the results as described by
+            <https://heliophysicsdata.gsfc.nasa.gov/WebServices/hdpspase.xsd>
+            with the addition of the following key/values:<br>
+            - HttpStatus: with the value of the HTTP status code.
+              Successful == 200.<br>
+            When HttpStatus != 200:<br>
+            - HttpText: containing a string representation of the HTTP
+              entity body.<br>
+            When HttpText is a standard HDP WS error entity body the
+            following key/values (convenience to avoid parsing
+            HttpStatus):<br>
+            - ErrorMessage: value from HttpText.<br>
+            - ErrorDescription: value from HttpText.<br>
+        """
+        return self.__get_complex_resource([ResourceType.CATALOG], query, date_range)
 
 
     def __get_simple_resource(
@@ -508,6 +607,74 @@ class HdpWs:
         return result
 
 
+    def __get_complex_resource(
+            self,
+            resource_types: List[ResourceType],
+            query: Dict,
+            date_range: Union[List[str], DateInterval] = None
+        ) -> Dict:
+        """
+        Gets the specified SPASE documents from HDP.
+
+        Parameters
+        ----------
+        resource_types
+            List of SPASE ResourceTypes to get.
+        query
+            Dictionary containing query parameters and values.
+        date_range
+            A DateInterval or two element array of ISO 8601 string
+            values of the start and stop date of the requested resources.
+            for example,<pre>
+            date_range = ['2022-01-01', '2022-01-02']
+            </pre>
+
+        Returns
+        -------
+            Dictionary containing a 'Result' key with a value of an
+            ElementTree representation of the results as described by
+            <https://heliophysicsdata.gsfc.nasa.gov/WebServices/hdpspase.xsd>
+            with the addition of the following key/values:<br>
+            - HttpStatus: with the value of the HTTP status code.
+              Successful == 200.<br>
+            When HttpStatus != 200:<br>
+            - HttpText: containing a string representation of the HTTP
+              entity body.<br>
+            When HttpText is a standard HDP WS error entity body the
+            following key/values (convenience to avoid parsing
+            HttpStatus):<br>
+            - ErrorMessage: value from HttpText.<br>
+            - ErrorDescription: value from HttpText.<br>
+        """
+        resource_path = ';'.join(type.value for type in resource_types)
+        url = self._endpoint + 'Spase/' + resource_path
+
+        if date_range is not None:
+
+            if isinstance(date_range, list):
+                date_interval = DateInterval(date_range[0], date_range[1])
+            else:
+                date_interval = date_range
+
+            url += '/' + str(date_interval)
+
+        response = self._session.get(url, params=query,
+                                     timeout=self._timeout)
+
+        self.logger.debug('response.url = %s', response.url)
+
+        status = self.__get_status(response)
+        if response.status_code != 200:
+            return status
+
+        result = {
+            'Result': ET.fromstring(response.text)
+        }
+
+        result.update(status)
+        return result
+
+
     @staticmethod
     def __get_status(
             response: requests.Response
